@@ -1,8 +1,6 @@
 package LinkLocal::IPv4::Interface::Cache;
 
-our $VERSION = '0.19_01';
-
-require 5.010_000;
+require 5.010000;
 
 # Copyright (C) 2010 Raymond Mroz, Tony Li Xu
 #
@@ -46,6 +44,7 @@ sub _build_cache {
     my $filename;    # Cache file name
 
     try {
+
         # Determine the file name based on OS
         given ($^O) {
             when ( m/linux/ || m/bsd/ ) {    # Linux || (Free|Open|Net)BSD
@@ -66,7 +65,7 @@ sub _build_cache {
         }
 
         # Create IO::File object and return
-        return new IO::File( $filename, O_RDWR | O_CREAT );
+        return new IO::File( "$filename", O_RDWR | O_CREAT );
     }
     catch {
         die "Error while opening cache file: $!";
@@ -161,15 +160,7 @@ LinkLocal::IPv4::Interface::Cache - IPv4 link-local address caching object.
 
   use LinkLocal::IPv4::Interface::Cache;
 
-  # Create a cache file object
-  my $cache = LinkLocal::IPv4::Interface::Cache->new();
-  
-  # Get the last IP cached for a given interface
-  my $last_address = $cache->get_last_ip('eth0');
-  
-  # Update the cache when an interface has successfully
-  # configured a link-local address
-  $cache->cache_this_ip( 'eth0', '169.254.100.150' );
+
 
 =head1 DESCRIPTION
 
@@ -222,8 +213,7 @@ interface, on the system.
 
 get_last_ip() is a public method which takes one argument, a network interface device name 
 (such as 'eth0' for example) and it returns the last successfully configured IPv4 link-local address
-which was configured on that interface or undef if this interface has never been dynamically
-configured with a link-local address. L<MooseX::Params::Validate> is in effect on all arguments.
+which was configured on that interface. L<MooseX::Params::Validate> is in effect on all arguments.
 
 =item C<cache_this_ip>
 
@@ -281,10 +271,6 @@ L<Try::Tiny>, L<Moose>
 This project is also hosted on github at:
 	git@github.com:raymroz/LinkLocal--IPv4.git
 
-=head1 BUGS
-
-What's a bug???
-
 =head1 AUTHOR
 
 Tony Li Xu, E<lt>tonylixu@gmail.comE<gt>
